@@ -7,13 +7,14 @@ import atexit as _atexit
 import sys as _sys
 
 from . import _defaults
+from ._logger import Core as _Core
 from ._logger import Logger as _Logger
 
-__version__ = "0.3.2"
+__version__ = "0.4.1"
 
 __all__ = ["logger"]
 
-logger = _Logger(None, 0, False, False, False, False, None, {})
+logger = _Logger(_Core(), None, 0, False, False, False, False, None, {})
 
 if _defaults.LOGURU_AUTOINIT and _sys.stderr:
     logger.add(_sys.stderr)
